@@ -1,7 +1,7 @@
 #
 # This file is part of Orchid and related technologies.
 #
-# Copyright (c) 2017-2021 Reveal Energy Services.  All Rights Reserved.
+# Copyright (c) 2017-2022 Reveal Energy Services.  All Rights Reserved.
 #
 # LEGAL NOTICE:
 # Orchid contains trade secrets and otherwise confidential information
@@ -22,7 +22,7 @@ def transform_display_name(net_display_name):
     return maybe_display_name.expect('Unexpected value, `None`, for `display_name`.')
 
 
-class DomProjectObject(dna.DotNetAdapter):
+class DomProjectObject(dna.IdentifiedDotNetAdapter):
     name = dna.dom_property('name', 'The name of this data frame.')
     display_name = dna.transformed_dom_property('display_name', 'The display name of this data frame.',
                                                 transform_display_name)
