@@ -1,4 +1,4 @@
-#  Copyright 2017-2021 Reveal Energy Services, Inc 
+#  Copyright (c) 2017-2022 Reveal Energy Services, Inc 
 #
 #  Licensed under the Apache License, Version 2.0 (the "License"); 
 #  you may not use this file except in compliance with the License. 
@@ -193,7 +193,7 @@ def as_measurement(unknown, _maybe_net_quantity: option.Option[UnitsNet.IQuantit
         unknown: A parameter whose type is not expected.
         _maybe_net_quantity: The optional .NET `IQuantity` instance to convert. (Unused.)
     """
-    raise TypeError(f'First argument, {unknown}, has type {type(unknown)}, unexpected by `deprecated_as_measurement`.')
+    raise TypeError(f'First argument, {unknown}, has type {type(unknown)}, unexpected by `as_measurement`.')
 
 
 # noinspection PyUnresolvedReferences
@@ -230,8 +230,9 @@ def as_measurement_in_specified_unit(target_unit,
         The equivalent `Quantity` instance in the target unit.
     """
 
-    return maybe_net_quantity.map_or(_as_measurement_in_unit(target_unit),
-                                     om.Quantity(float('NaN'), target_unit.value.unit))
+    result = maybe_net_quantity.map_or(_as_measurement_in_unit(target_unit),
+                                       om.Quantity(float('NaN'), target_unit.value.unit))
+    return result
 
 
 @toolz.curry
@@ -378,7 +379,7 @@ def as_net_quantity_using_common_units(to_common_unit, measurement: om.Quantity)
 @toolz.curry
 def as_net_quantity_in_specified_unit(specified_unit, measurement: om.Quantity) -> UnitsNet.IQuantity:
     """
-    Convert a .NET UnitsNet.IQuantity to a `pint` `Quantity` instance in a specified, but compatible unit.
+    Convert a `pint` `Quantity` to a .NET UnitsNet.IQuantity instance in a specified, but compatible unit.
 
     Args:
         specified_unit: The unit for the converted `Quantity` instance.
